==> mybb-1.4.10_1.tbz: www/mybb/inc/languages/english/admin/global.lang.php <==
<?php
/**
 * MyBB 1.4 English Language Pack
 * Copyright  2008 MyBB Group, All Rights Reserved
 * 
 * $Id: global.lang.php 4309 2009-01-17 18:36:01Z Tikitiki $
 */
 
$l['today'] = "Today";
$l['yesterday'] = "Yesterday";

$l['size_yb'] = "YB";
$l['size_zb'] = "ZB";
$l['size_eb'] = "EB";
$l['size_pb'] = "PB";
$l['size_tb'] = "TB";
$l['size_gb'] = "GB";
$l['size_mb'] = "MB";
$l['size_kb'] = "KB";
$l['size_bytes'] = "bytes";
$l['na'] = "N/A";

// Header language strings
$l['mybb_admin_panel'] = "MyBB Control Panel";
$l['mybb_admin_cp'] = "MyBB Admin CP";
$l['logged_in_as'] = "Logged in as";
$l['view_board'] = "View Forum";
$l['logout'] = "Log Out";

// Footer language strings
$l['generated_in'] = "Generated in {1} seconds with {2} queries.";

// Login page
$l['enter_username_and_password'] = "Please enter your username and password to continue.";
$l['mybb_admin_login'] = "MyBB Control Panel - Login";
$l['return_to_forum'] = "Return to forum";
$l['please_login'] = "Please Login";
$l['username'] = "Username:";
$l['password'] = "Password:";
$l['login'] = "Login";
$l['lost_password'] = "Forgot your password?";

$l['error_invalid_admin_session'] = "Invalid administration session";
$l['error_admin_session_expired'] = "Your administration session has expired";
$l['error_invalid_ip'] = "Your IP address is not valid for this session";

$l['success_logged_out'] = "You have been logged out successfully.";
$l['error_invalid_username_password'] = "The username and password combination you entered is invalid.";

// Action Confirmation
$l['confirm_action'] = "Are you sure you wish to perform this action?";

// Common words and phrases
$l['home'] = "Home";
$l['name'] = "Name";
$l['size'] = "Size";
$l['controls'] = "Controls";
$l['view'] = "View";
$l['yes'] = "Yes";
$l['no'] = "No";
$l['options'] = "Options";
$l['proceed'] = "Proceed";
$l['ok'] = "OK";
$l['error'] = "Error";
$l['edit'] = "Edit";
$l['never'] = "Never";
$l['legend'] = "Legend";
$l['version'] = "Version";
$l['languagevar'] = "Language";
$l['use_default'] = "Use Default";
$l['file'] = "File";
$l['go'] = "Go";
$l['unknown'] = "Unknown";
$l['year'] = "Year";
$l['year_short'] = "y";
$l['years'] = "Years";
$l['years_short'] = "y";
$l['month'] = "Month";
$l['month_short'] = "m";
$l['months'] = "Months";
$l['months_short'] = "m";
$l['week'] = "Week";
$l['week_short'] = "w";
$l['weeks'] = "Weeks";
$l['weeks_short'] = "w";
$l['day'] = "Day";
$l['day_short'] = "d";
$l['days'] = "Days";
$l['days_short'] = "d";
$l['hour'] = "Hour";
$l['hour_short'] = "h";
$l['hours'] = "Hours";
$l['hours_short'] = "h";
$l['minute'] = "Minute";
$l['minute_short'] = "m";
$l['minutes'] = "Minutes";
$l['minutes_short'] = "m";
$l['second'] = "Second";
$l['second_short'] = "s";
$l['seconds'] = "Seconds";
$l['seconds_short'] = "s";
$l['permanent'] = "Permanent";
$l['all_forums'] = "All Forums";
$l['mybb_acp'] = "MyBB ACP";
$l['pages'] = "Pages";
$l['previous'] = "Previous";
$l['page'] = "Page";
$l['next'] = "Next";
$l['delete'] = "Delete";
$l['reset'] = "Reset";
$l['and'] = "and";
$l['go'] = "Go";
$l['on'] = "On";
$l['off'] = "Off";

// Parser bits
$l['quote'] = "Quote:";
$l['wrote'] = "Wrote:";
$l['code'] = "Code:";
$l['php_code'] = "PHP Code:";
$l['linkback'] = "Original Post";

// The months of the year
$l['january'] = "January";
$l['february'] = "February";
$l['march'] = "March";
$l['april'] = "April";
$l['may'] = "May";
$l['june'] = "June";
$l['july'] = "July";
$l['august'] = "August";
$l['september'] = "September";
$l['october'] = "October";
$l['november'] = "November";
$l['december'] = "December";

// Access Denied
$l['access_denied'] = "Access Denied";
$l['access_denied_desc'] = "You do not have permission to access this part of the administration control panel.";

// Super Administrator required
$l['cannot_perform_action_super_admin_general'] = "Sorry, but you cannot perform this action because you are not a super administrator.<br /><br />To be able to perform this action, you need to add your user ID to the list of super administrators in inc/config.php.";

// AJAX
$l['loading_text'] = "Loading<br />Please wait...";

// Time zone selection boxes
$l['timezone_gmt_minus_1200'] = "(GMT -12:00) Eniwetok, Kwajalein";
$l['timezone_gmt_minus_1100'] = "(GMT -11:00) Nome, Midway Island, Samoa";
$l['timezone_gmt_minus_1000'] = "(GMT -10:00) Hawaii";
$l['timezone_gmt_minus_900'] = "(GMT -9:00) Alaska";
$l['timezone_gmt_minus_800'] = "(GMT -8:00) Pacific Time";
$l['timezone_gmt_minus_700'] = "(GMT -7:00) Mountain Time";
$l['timezone_gmt_minus_600'] = "(GMT -6:00) Central Time, Mexico City";
$l['timezone_gmt_minus_500'] = "(GMT -5:00) Eastern Time, Bogota, Lima, Quito";
$l['timezone_gmt_minus_450'] = "(GMT -4:30) Venezuela (September)";
$l['timezone_gmt_minus_400'] = "(GMT -4:00) Atlantic Time, Caracas, La Paz";
$l['timezone_gmt_minus_350'] = "(GMT -3:30) Newfoundland";
$l['timezone_gmt_minus_300'] = "(GMT -3:00) Brazil, Buenos Aires, Georgetown, Falkland Is.";
$l['timezone_gmt_minus_200'] = "(GMT -2:00) Mid-Atlantic, Ascension Is., St Helena";
$l['timezone_gmt_minus_100'] = "(GMT -1:00) Azores, Cape Verde Islands";
$l['timezone_gmt'] = "(GMT) Casablanca, Dublin, Edinburgh, London, Lisbon, Monrovia";
$l['timezone_gmt_100'] = "(GMT +1:00) Berlin, Brussels, Copenhagen, Madrid, Paris, Rome";
$l['timezone_gmt_200'] = "(GMT +2:00) Kaliningrad, South Africa, Warsaw";
$l['timezone_gmt_300'] = "(GMT +3:00) Baghdad, Riyadh, Moscow, Nairobi";
$l['timezone_gmt_350'] = "(GMT +3:30) Tehran";
$l['timezone_gmt_400'] = "(GMT +4:00) Abu Dhabi, Baku, Muscat, Tbilisi";
$l['timezone_gmt_450'] = "(GMT +4:30) Kabul";
$l['timezone_gmt_500'] = "(GMT +5:00) Islamabad, Karachi, Tashkent";
$l['timezone_gmt_550'] = "(GMT +5:30) Mumbai, Calcutta, Madras, New Delhi";
$l['timezone_gmt_600'] = "(GMT +6:00) Almaty, Colomba, Dhakra";
$l['timezone_gmt_700'] = "(GMT +7:00) Bangkok, Hanoi, Jakarta";
$l['timezone_gmt_800'] = "(GMT +8:00) Beijing, Hong Kong, Perth, Singapore, Taipei";
$l['timezone_gmt_900'] = "(GMT +9:00) Osaka, Sapporo, Seoul, Tokyo, Yakutsk";
$l['timezone_gmt_950'] = "(GMT +9:30) Adelaide, Darwin";
$l['timezone_gmt_1000'] = "(GMT +10:00) Melbourne, Papua New Guinea, Sydney, Vladivostok";
$l['timezone_gmt_1100'] = "(GMT +11:00) Magadan, New Caledonia, Solomon Islands";
$l['timezone_gmt_1200'] = "(GMT +12:00) Auckland, Wellington, Fiji, Marshall Island";
$l['timezone_gmt_short'] = "GMT {1}({2})";

// Global language strings used for log deletion pages
$l['confirm_delete_logs'] = "Prune the selected log entries?";
$l['confirm_delete_all_logs'] = "Prune all log entries?";
$l['selected_logs_deleted'] = "The selected log entries have been deleted.";
$l['all_logs_deleted'] = "All log entries have been deleted.";
$l['delete_selected'] = "Delete Selected";
$l['delete_all'] = "Delete All Filtered";

// Misc
$l['encountered_errors'] = "The following errors were encountered:";
$l['invalid_post_verify_key'] = "An authorization code mismatch occurred. Please confirm that you wish to perform the action below.";
$l['invalid_post_verify_key2'] = "An authorization code mismatch occurred. Please double check that you are accessing this page correctly.";
$l['forums_colon'] = "Forums:";

// Code buttons editor language strings
$l['editor_title_bold'] = "Insert bold text";
$l['editor_title_italic'] = "Insert italic text";
$l['editor_title_underline'] = "Insert underlined text";
$l['editor_title_left'] = "Align text to the left";
$l['editor_title_center'] = "Align text to the center";
$l['editor_title_right'] = "Align text to the right";
$l['editor_title_justify'] = "Justify text";
$l['editor_title_numlist'] = "Insert numbered list";
$l['editor_title_bulletlist'] = "Insert bulleted list";
$l['editor_title_image'] = "Insert image";
$l['editor_title_hyperlink'] = "Insert hyperlink";
$l['editor_title_email'] = "Insert email address";
$l['editor_title_quote'] = "Insert quoted text";
$l['editor_title_code'] = "Insert formatted code";
$l['editor_title_php'] = "Insert formatted PHP code";
$l['editor_title_close_tags'] = "Close any open MyCode tags that you currently have open";
$l['editor_enter_list_item'] = "Enter a list item. Click cancel or leave blank to end the list.";
$l['editor_enter_url'] = "Please enter the URL of the website.";
$l['editor_enter_url_title'] = "Optionally, you can also enter a title for the URL.";
$l['editor_enter_email'] = "Please enter the email address you wish to insert.";
$l['editor_enter_email_title'] = "Optionally, you may also enter a title for the email address.";
$l['editor_enter_image'] = "Please enter the remote URL of the image you wish to insert.";
$l['editor_size_xx_small'] = "XX Small";
$l['editor_size_x_small'] = "X Small";
$l['editor_size_small'] = "Small";
$l['editor_size_medium'] = "Medium";
$l['editor_size_large'] = "Large";
$l['editor_size_x_large'] = "X Large";
$l['editor_size_xx_large'] = "XX Large";
$l['editor_font'] = "Font";
$l['editor_size'] = "Text Size";
$l['editor_color'] = "Text Color";

$l['missing_task'] = "Error: Task file does not exist";
$l['task_backup_cannot_write_backup'] = "Error: The database backup task cannot write to backups directory.";
$l['task_backup_ran'] = "The database backup task successfully ran.";
$l['task_checktables_ran'] = "The check tables task successfully ran with no corrupted tables found.";
$l['task_checktables_ran_found'] = "Notice: The check tables task successfully ran and repaired the {1} table(s).";
$l['task_dailycleanup_ran'] = "The daily cleanup task successfully ran.";
$l['task_hourlycleanup_ran'] = "The hourly cleanup task successfully ran.";
$l['task_logcleanup_ran'] = "The log cleanup task successfully ran and pruned any old logs.";
$l['task_promotions_ran'] = "The promotions task successfully ran.";
$l['task_threadviews_ran'] = "The thread views task successfully ran.";
$l['task_usercleanup_ran'] = "The user cleanup task successfully ran.";
$l['task_massmail_ran'] = "The mass mail task successfully ran.";
$l['task_massmail_ran_errors'] = "One or more problems occured sending to \"{1}\":
{2}";

$l['massmail_username'] = "Username";
$l['email_addr'] = "Email Address";
$l['board_name'] = "Board Name";
$l['board_url'] = "Board URL";

// If the language string for "Username" is too cramped in the ACP Login box
// then use this to define how much larger you want the gap to be (in px)
// $l['login_field_width'] = "0";
?>

==> mybb-1.6.6.tbz: www/mybb/inc/languages/english/admin/global.lang.php <==
<?php
/**
 * MyBB 1.6 English Language Pack
 * Copyright 2010 MyBB Group, All Rights Reserved
 * 
 * $Id: global.lang.php 5583 2011-09-13 10:32:05Z Tomm $
 */
 
$l['today'] = "Today";
$l['yesterday'] = "Yesterday";

$l['size_yb'] = "YB";
$l['size_zb'] = "ZB";
$l['size_eb'] = "EB";
$l['size_pb'] = "PB";
$l['size_tb'] = "TB";
$l['size_gb'] = "GB";
$l['size_mb'] = "MB";
$l['size_kb'] = "KB";
$l['size_bytes'] = "bytes";
$l['na'] = "N/A";

// Header language strings
$l['mybb_admin_panel'] = "MyBB Control Panel";
$l['mybb_admin_cp'] = "MyBB Admin CP";
$l['logged_in_as'] = "Logged in as";
$l['view_board'] = "View Forum";
$l['logout'] = "Log Out";

// Footer language strings
$l['generated_in'] = "Generated in {1} seconds with {2} queries. Memory Usage: {3}";

// Login page
$l['enter_username_and_password'] = "Please enter your username and password to continue.";
$l['mybb_admin_login'] = "MyBB Control Panel - Login";
$l['return_to_forum'] = "Return to forum";
$l['please_login'] = "Please Login";
$l['username'] = "Username:";
$l['password'] = "Password:";
$l['login'] = "Login";
$l['lost_password'] = "Forgot your password?";

$l['error_invalid_admin_session'] = "Invalid administration session";
$l['error_admin_session_expired'] = "Your administration session has expired";
$l['error_invalid_ip'] = "Your IP address is not valid for this session";
$l['error_mybb_admin_lockedout'] = "This account has been locked out";
$l['error_mybb_admin_lockedout_message'] = "Your account is currently locked out after failing to login {1} times. You have been sent an email with instructions on how to unlock your account.";

$l['success_logged_out'] = "You have been logged out successfully.";
$l['error_invalid_username_password'] = "The username and password combination you entered is invalid.";

// Action Confirmation
$l['confirm_action'] = "Are you sure you wish to perform this action?";

// Common words and phrases
$l['home'] = "Home";
$l['name'] = "Name";
$l['size'] = "Size";
$l['controls'] = "Controls";
$l['view'] = "View";
$l['yes'] = "Yes";
$l['no'] = "No";
$l['cancel'] = "Cancel";
$l['options'] = "Options";
$l['proceed'] = "Proceed";
$l['ok'] = "OK";
$l['error'] = "Error";
$l['edit'] = "Edit";
$l['never'] = "Never";
$l['legend'] = "Legend";
$l['version'] = "Version";
$l['languagevar'] = "Language";
$l['use_default'] = "Use Default";
$l['file'] = "File";
$l['go'] = "Go";
$l['clear'] = "Clear";
$l['unknown'] = "Unknown";
$l['year'] = "Year";
$l['year_short'] = "y";
$l['years'] = "Years";
$l['years_short'] = "y";
$l['month'] = "Month";
$l['month_short'] = "m";
$l['months'] = "Months";
$l['months_short'] = "m";
$l['week'] = "Week";
$l['week_short'] = "w";
$l['weeks'] = "Weeks";
$l['weeks_short'] = "w";
$l['day'] = "Day";
$l['day_short'] = "d";
$l['days'] = "Days";
$l['days_short'] = "d";
$l['hour'] = "Hour";
$l['hour_short'] = "h";
$l['hours'] = "Hours";
$l['hours_short'] = "h";
$l['minute'] = "Minute";
$l['minute_short'] = "m";
$l['minutes'] = "Minutes";
$l['minutes_short'] = "m";
$l['second'] = "Second";
$l['second_short'] = "s";
$l['seconds'] = "Seconds";
$l['seconds_short'] = "s";
$l['permanent'] = "Permanent";
$l['all_forums'] = "All Forums";
$l['mybb_acp'] = "MyBB ACP";
$l['pages'] = "Pages";
$l['previous'] = "Previous";
$l['page'] = "Page";
$l['next'] = "Next";
$l['delete'] = "Delete";
$l['reset'] = "Reset";
$l['and'] = "and";
$l['on'] = "On";
$l['off'] = "Off";

// Parser bits
$l['quote'] = "Quote:";
$l['wrote'] = "Wrote:";
$l['code'] = "Code:";
$l['php_code'] = "PHP Code:";
$l['linkback'] = "Original Post";

// The months of the year
$l['january'] = "January";
$l['february'] = "February";
$l['march'] = "March";
$l['april'] = "April";
$l['may'] = "May";
$l['june'] = "June";
$l['july'] = "July";
$l['august'] = "August";
$l['september'] = "September";
$l['october'] = "October";
$l['november'] = "November";
$l['december'] = "December";

// Access Denied
$l['access_denied'] = "Access Denied";
$l['access_denied_desc'] = "You do not have permission to access this part of the administration control panel.";

// Super Administrator required
$l['cannot_perform_action_super_admin_general'] = "Sorry, but you cannot perform this action because you are not a super administrator.<br /><br />To be able to perform this action, you need to add your user ID to the list of super administrators in inc/config.php.";

// AJAX
$l['loading_text'] = "Loading<br />Please wait...";

// Time zone selection boxes
$l['timezone_gmt_minus_1200'] = "(GMT -12:00) Eniwetok, Kwajalein";
$l['timezone_gmt_minus_1100'] = "(GMT -11:00) Nome, Midway Island, Samoa";
$l['timezone_gmt_minus_1000'] = "(GMT -10:00) Hawaii";
$l['timezone_gmt_minus_900'] = "(GMT -9:00) Alaska";
$l['timezone_gmt_minus_800'] = "(GMT -8:00) Pacific Time";
$l['timezone_gmt_minus_700'] = "(GMT -7:00) Mountain Time";
$l['timezone_gmt_minus_600'] = "(GMT -6:00) Central Time, Mexico City";
$l['timezone_gmt_minus_500'] = "(GMT -5:00) Eastern Time, Bogota, Lima, Quito";
$l['timezone_gmt_minus_450'] = "(GMT -4:30) Venezuela (September)";
$l['timezone_gmt_minus_400'] = "(GMT -4:00) Atlantic Time, Caracas, La Paz";
$l['timezone_gmt_minus_350'] = "(GMT -3:30) Newfoundland";
$l['timezone_gmt_minus_300'] = "(GMT -3:00) Brazil, Buenos Aires, Georgetown, Falkland Is.";
$l['timezone_gmt_minus_200'] = "(GMT -2:00) Mid-Atlantic, Ascension Is., St Helena";
$l['timezone_gmt_minus_100'] = "(GMT -1:00) Azores, Cape Verde Islands";
$l['timezone_gmt'] = "(GMT) Casablanca, Dublin, Edinburgh, London, Lisbon, Monrovia";
$l['timezone_gmt_100'] = "(GMT +1:00) Berlin, Brussels, Copenhagen, Madrid, Paris, Rome";
$l['timezone_gmt_200'] = "(GMT +2:00) Kaliningrad, South Africa, Warsaw";
$l['timezone_gmt_300'] = "(GMT +3:00) Baghdad, Riyadh, Moscow, Nairobi";
$l['timezone_gmt_350'] = "(GMT +3:30) Tehran";
$l['timezone_gmt_400'] = "(GMT +4:00) Abu Dhabi, Baku, Muscat, Tbilisi";
$l['timezone_gmt_450'] = "(GMT +4:30) Kabul";
$l['timezone_gmt_500'] = "(GMT +5:00) Islamabad, Karachi, Tashkent";
$l['timezone_gmt_550'] = "(GMT +5:30) Mumbai, Calcutta, Madras, New Delhi";
$l['timezone_gmt_600'] = "(GMT +6:00) Almaty, Colomba, Dhakra";
$l['timezone_gmt_700'] = "(GMT +7:00) Bangkok, Hanoi, Jakarta";
$l['timezone_gmt_800'] = "(GMT +8:00) Beijing, Hong Kong, Perth, Singapore, Taipei";
$l['timezone_gmt_900'] = "(GMT +9:00) Osaka, Sapporo, Seoul, Tokyo, Yakutsk";
$l['timezone_gmt_950'] = "(GMT +9:30) Adelaide, Darwin";
$l['timezone_gmt_1000'] = "(GMT +10:00) Melbourne, Papua New Guinea, Sydney, Vladivostok";
$l['timezone_gmt_1100'] = "(GMT +11:00) Magadan, New Caledonia, Solomon Islands";
$l['timezone_gmt_1200'] = "(GMT +12:00) Auckland, Wellington, Fiji, Marshall Island";
$l['timezone_gmt_short'] = "GMT {1}({2})";

// Global language strings used for log deletion pages
$l['confirm_delete_logs'] = "Prune the selected log entries?";
$l['confirm_delete_all_logs'] = "Prune all log entries?";
$l['selected_logs_deleted'] = "The selected log entries have been deleted.";
$l['all_logs_deleted'] = "All log entries have been deleted.";
$l['delete_selected'] = "Delete Selected";
$l['delete_all'] = "Delete All Filtered";

// Misc
$l['encountered_errors'] = "The following errors were encountered:";
$l['invalid_post_verify_key'] = "An authorization code mismatch occurred. Please confirm that you wish to perform the action below.";
$l['invalid_post_verify_key2'] = "An authorization code mismatch occurred. Please double check that you are accessing this page correctly.";
$l['forums_colon'] = "Forums:";

// Code buttons editor language strings
$l['editor_title_bold'] = "Insert bold text";
$l['editor_title_italic'] = "Insert italic text";
$l['editor_title_underline'] = "Insert underlined text";
$l['editor_title_left'] = "Align text to the left";
$l['editor_title_center'] = "Align text to the center";
$l['editor_title_right'] = "Align text to the right";
$l['editor_title_justify'] = "Justify text";
$l['editor_title_numlist'] = "Insert numbered list";
$l['editor_title_bulletlist'] = "Insert bulleted list";
$l['editor_title_image'] = "Insert image";
$l['editor_title_hyperlink'] = "Insert hyperlink";
$l['editor_title_email'] = "Insert email address";
$l['editor_title_quote'] = "Insert quoted text";
$l['editor_title_code'] = "Insert formatted code";
$l['editor_title_php'] = "Insert formatted PHP code";
$l['editor_title_close_tags'] = "Close any open MyCode tags that you currently have open";
$l['editor_enter_list_item'] = "Enter a list item. Click cancel or leave blank to end the list.";
$l['editor_enter_url'] = "Please enter the URL of the website.";
$l['editor_enter_url_title'] = "Optionally, you can also enter a title for the URL.";
$l['editor_enter_email'] = "Please enter the email address you wish to insert.";
$l['editor_enter_email_title'] = "Optionally, you may also enter a title for the email address.";
$l['editor_enter_image'] = "Please enter the remote URL of the image you wish to insert.";
$l['editor_enter_video_url'] = "Please enter the URL of the video.";
$l['editor_video_dailymotion'] = "Dailymotion";
$l['editor_video_metacafe'] = "MetaCafe";
$l['editor_video_myspacetv'] = "MySpace TV";
$l['editor_video_vimeo'] = "Vimeo";
$l['editor_video_yahoo'] = "Yahoo Video";
$l['editor_video_youtube'] = "YouTube";
$l['editor_size_xx_small'] = "XX Small";
$l['editor_size_x_small'] = "X Small";
$l['editor_size_small'] = "Small";
$l['editor_size_medium'] = "Medium";
$l['editor_size_large'] = "Large";
$l['editor_size_x_large'] = "X Large";
$l['editor_size_xx_large'] = "XX Large";
$l['editor_font'] = "Font";
$l['editor_size'] = "Text Size";
$l['editor_color'] = "Text Color";

$l['missing_task'] = "Error: Task file does not exist";
$l['task_backup_cannot_write_backup'] = "Error: The database backup task cannot write to backups directory.";
$l['task_backup_ran'] = "The database backup task successfully ran.";
$l['task_checktables_ran'] = "The check tables task successfully ran with no corrupted tables found.";
$l['task_checktables_ran_found'] = "Notice: The check tables task successfully ran and repaired the {1} table(s).";
$l['task_dailycleanup_ran'] = "The daily cleanup task successfully ran.";
$l['task_hourlycleanup_ran'] = "The hourly cleanup task successfully ran.";
$l['task_logcleanup_ran'] = "The log cleanup task successfully ran and pruned any old logs.";
$l['task_promotions_ran'] = "The promotions task successfully ran.";
$l['task_threadviews_ran'] = "The thread views task successfully ran.";
$l['task_usercleanup_ran'] = "The user cleanup task successfully ran.";
$l['task_massmail_ran'] = "The mass mail task successfully ran.";
$l['task_userpruning_ran'] = "The user pruning task successfully ran.";
$l['task_delayedmoderation_ran'] = "The delayed moderation task successfully ran.";
$l['task_massmail_ran_errors'] = "One or more problems occured sending to \"{1}\":
{2}";

$l['massmail_username'] = "Username";
$l['email_addr'] = "Email Address";
$l['board_name'] = "Board Name";
$l['board_url'] = "Board URL";

// Unlock ACP
$l['lockout_unlock'] = "Unlock Admin Control Panel";
$l['enter_username_and_token'] = "Please enter your username and the activation code to continue.";
$l['unlock_token'] = "Activation code:";
$l['unlock_account'] = "Unlock Account";

// Email message for if an admin account has been locked out
$l['locked_out_subject'] = "Administrator Account Locked Out at {1}";
$l['locked_out_message'] = "{1},

Your administrator account at {2} has been locked after {3} failed login attempts.

To unlock your account, please go to the URL below in your web browser.

{4}/{5}/index.php?action=unlock&token={6}

If the above link does not work correctly, go to

{4}/{5}/index.php?action=unlock

You will need to enter the following:
Username: {1}
Activation Code: {6}

Thank you,
{2} Staff";

$l['comma'] = ", ";

// If the language string for "Username" is too cramped in the ACP Login box
// then use this to define how much larger you want the gap to be (in px)
// $l['login_field_width'] = "0";
?>
